@@ -27,9 +27,9 @@
 #endif
 
 #include "fht.h"     //stack allocated and convenience
-#include <qpixmap.h> //stack allocated and convenience
-#include <qtimer.h>  //stack allocated
-#include <qwidget.h> //baseclass
+#include <QPixmap> //stack allocated and convenience
+#include <QTimer>  //stack allocated
+#include <QWidget> //baseclass
 #include <vector>    //included for convenience
 
 #include <phonon/audiodataoutput.h>
@@ -47,19 +47,19 @@ class Base : public QWidget
 {
     Q_OBJECT
 
-public slots:
+public Q_SLOTS:
     void drawFrame(const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > &thescope);
 
 protected:
     Base(QWidget*, uint = 7);
-    ~Base() { delete m_fht; }
+    ~Base() override { delete m_fht; }
 
     int  resizeExponent(int);
     int  resizeForBands(int);
     virtual void transform(QVector<float>&);
     virtual void analyze(const QVector<float>&) = 0;
     virtual void paused();
-public slots:
+public Q_SLOTS:
     void demo();
 protected:
     FHT *m_fht;
@@ -72,7 +72,7 @@ class Base2D : public Base
 public:
     const QPixmap *canvas() const { return &m_canvas; }
 
-    // private slots:
+    // private Q_SLOTS:
     //     void draw() { drawFrame(); bitBlt( this, 0, 0, canvas() ); }
 
     void enableDemo(bool enable) { enable ? timer.start() : timer.stop(); }
@@ -85,11 +85,11 @@ protected:
     QPixmap     *canvas() { return &m_canvas; }
     void    eraseCanvas() { m_canvas.fill(Qt::transparent); }
 
-    void paintEvent( QPaintEvent* ) Q_DECL_OVERRIDE;
-    void resizeEvent( QResizeEvent* ) Q_DECL_OVERRIDE;
+    void paintEvent( QPaintEvent* ) override;
+    void resizeEvent( QResizeEvent* ) override;
 
 
-protected slots:
+protected Q_SLOTS:
     virtual void init() {}
 
 private:
