@@ -59,6 +59,7 @@
 #include <KIO/StatJob>
 #include <KLocalizedString>
 #include <KActionMenu>
+#include <kio_version.h>
 
 #include <Phonon/VideoWidget>
 #include <Phonon/BackendCapabilities>
@@ -129,7 +130,7 @@ MainWindow::MainWindow()
 
     setFocusProxy( videoWindow() ); // essential! See VideoWindow::event(), QEvent::FocusOut
 
-    m_titleLabel->setMargin( 2 );
+    m_titleLabel->setContentsMargins( 2 ,  2 ,  2 ,  2 );
     m_titleLabel->setSizePolicy(QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ));
 
     // FIXME work around a bug in KStatusBar
@@ -150,9 +151,9 @@ MainWindow::MainWindow()
         menuAction->setEnabled( false ); \
         connect( menuAction->menu(), SIGNAL(aboutToShow()), SLOT(aboutToShowMenu()) ); \
         ac->addAction( menuAction->objectName(), menuAction );
-        make_menu( QLatin1String( "aspect_ratio_menu" ), i18n( "Aspect &Ratio" ) );
-        make_menu( QLatin1String( "audio_channels_menu" ), i18n( "&Audio Channels" ) );
-        make_menu( QLatin1String( "subtitle_channels_menu" ), i18n( "&Subtitles" ) );
+        make_menu( QLatin1String( "aspect_ratio_menu" ), i18nc("@title:menu", "Aspect &Ratio" ) );
+        make_menu( QLatin1String( "audio_channels_menu" ), i18nc("@title:menu", "&Audio Channels") );
+        make_menu( QLatin1String( "subtitle_channels_menu" ), i18nc("@title:menu", "&Subtitles") );
 #undef make_menu
         {
             m_aspectRatios = new QActionGroup( this );
@@ -167,10 +168,10 @@ MainWindow::MainWindow()
     ac->addAction( objectname, ratioAction ); \
     connect( ratioAction, SIGNAL(triggered()), this, SLOT(streamSettingChange()) ); \
 }
-            make_ratio_action( i18n( "Determine &Automatically" ), QLatin1String( "ratio_auto" ),  Phonon::VideoWidget::AspectRatioAuto );
-            make_ratio_action( i18n( "&4:3" ), QLatin1String( "ratio_golden" ), Phonon::VideoWidget::AspectRatio4_3 );
-            make_ratio_action( i18n( "Ana&morphic (16:9)" ), QLatin1String( "ratio_anamorphic" ), Phonon::VideoWidget::AspectRatio16_9 );
-            make_ratio_action( i18n( "&Window Size" ), QLatin1String( "ratio_window" ), Phonon::VideoWidget::AspectRatioWidget );
+            make_ratio_action( i18nc("@option:radio aspect ratio", "Determine &Automatically"), QLatin1String( "ratio_auto" ),  Phonon::VideoWidget::AspectRatioAuto );
+            make_ratio_action( i18nc("@option:radio aspect ratio", "&4:3"), QLatin1String( "ratio_golden" ), Phonon::VideoWidget::AspectRatio4_3 );
+            make_ratio_action( i18nc("@option:radio aspect ratio", "Ana&morphic (16:9)"), QLatin1String( "ratio_anamorphic" ), Phonon::VideoWidget::AspectRatio16_9 );
+            make_ratio_action( i18nc("@option:radio aspect ratio", "&Window Size" ), QLatin1String( "ratio_window" ), Phonon::VideoWidget::AspectRatioWidget );
 #undef make_ratio_action
             ac->action( QLatin1String( "ratio_auto" ) )->setChecked( true );
             ac->action( QLatin1String( "aspect_ratio_menu" ) )->menu()->addActions( m_aspectRatios->actions() );
@@ -264,7 +265,7 @@ void MainWindow::wheelEvent (QWheelEvent *event)
         return;
     }
 
-    if (event->delta() > 0)
+    if (event->angleDelta().y() > 0)
         engine()->increaseVolume();
     else
         engine()->decreaseVolume();
@@ -278,7 +279,7 @@ MainWindow::setupActions()
 
     KStandardAction::quit( qApp, SLOT(closeAllWindows()), ac );
 
-    KStandardAction::open( this, SLOT(toggleLoadView()), ac )->setText( i18n("Play &Media...") );
+    KStandardAction::open( this, SLOT(toggleLoadView()), ac )->setText( i18nc("@action", "Play &Media...") );
 
 #define addToAc( X ) ac->addAction( X->objectName(), X );
 
@@ -307,25 +308,25 @@ MainWindow::setupActions()
     connect(action, SIGNAL(triggered()), engine(), SLOT(decreaseVolume()));
     addToAc(action);
 
-    QAction* playerStop = new QAction( QIcon::fromTheme(QLatin1String( "media-playback-stop" )), i18n("Stop"), ac );
+    QAction* playerStop = new QAction( QIcon::fromTheme(QLatin1String( "media-playback-stop" )), i18nc("@action", "Stop"), ac );
     playerStop->setObjectName( QLatin1String( "stop" ) );
     ac->setDefaultShortcuts(playerStop, QList<QKeySequence>() << Qt::Key_S << Qt::Key_MediaStop);
     connect( playerStop, SIGNAL(triggered()), this, SLOT(stop()) );
     addToAc( playerStop )
 
-    KToggleAction* mute = new KToggleAction( QIcon::fromTheme(QLatin1String( "player-volume-muted" )), i18nc( "Mute the sound output", "Mute"), ac );
+    KToggleAction* mute = new KToggleAction( QIcon::fromTheme(QLatin1String( "player-volume-muted" )), i18nc("@action Mute the sound output", "Mute"), ac );
     mute->setObjectName( QLatin1String( "mute" ) );
     ac->setDefaultShortcut(mute, Qt::Key_M);
     connect( mute, SIGNAL(toggled(bool)), videoWindow(), SLOT(mute(bool)) );
     addToAc( mute )
 
-    QAction* resetZoom = new QAction( QIcon::fromTheme(QLatin1String( "zoom-fit-best" )), i18n("Reset Video Scale"), ac );
+    QAction* resetZoom = new QAction( QIcon::fromTheme(QLatin1String( "zoom-fit-best" )), i18nc("@action", "Reset Video Scale"), ac );
     resetZoom->setObjectName( QLatin1String( "reset_zoom" ) );
     ac->setDefaultShortcut(resetZoom, Qt::Key_Equal);
     connect( resetZoom, SIGNAL(triggered()), videoWindow(), SLOT(resetZoom()) );
     addToAc( resetZoom )
 
-    QAction* dvdMenu = new QAction( QIcon::fromTheme(QLatin1String( "media-optical-video" )), i18n("Menu Toggle"), ac );
+    QAction* dvdMenu = new QAction( QIcon::fromTheme(QLatin1String( "media-optical-video" )), i18nc("@action", "Menu Toggle"), ac );
     dvdMenu->setObjectName( QLatin1String( "toggle_dvd_menu" ) );
     ac->setDefaultShortcut(dvdMenu, Qt::Key_R);
     connect( dvdMenu, SIGNAL(triggered()), engine(), SLOT(toggleDVDMenu()) );
@@ -337,14 +338,14 @@ MainWindow::setupActions()
     positionSlider->setDefaultWidget( m_positionSlider );
     addToAc( positionSlider )
 
-    QAction* videoSettings = new QAction( i18n("Video Settings"), ac );
+    QAction* videoSettings = new QAction( i18nc("@option:check", "Video Settings"), ac );
     videoSettings->setObjectName( QLatin1String( "video_settings" ) );
     videoSettings->setCheckable( true );
     connect( videoSettings, SIGNAL(toggled(bool)), this, SLOT(toggleVideoSettings(bool)) );
     addToAc( videoSettings )
 
     QAction* uniqueToggle =
-            new QAction( i18nc("@action:inmenu Whether only one instance of dragon can be started"
+            new QAction( i18nc("@option:check Whether only one instance of dragon can be started"
                                " and will be reused when the user tries to play another file.",
                                "One Instance Only"), ac );
     uniqueToggle->setObjectName( QLatin1String( "unique" ) );
@@ -353,39 +354,39 @@ MainWindow::setupActions()
     connect( uniqueToggle, SIGNAL(toggled(bool)), this, SLOT(toggleUnique(bool)) );
     addToAc( uniqueToggle )
 
-    QAction* prev_chapter = new QAction( QIcon::fromTheme(QLatin1String( "media-skip-backward" )), i18n("Previous"), ac );
+    QAction* prev_chapter = new QAction( QIcon::fromTheme(QLatin1String( "media-skip-backward" )), i18nc("@action previous chapter", "Previous"), ac );
     prev_chapter->setObjectName( QLatin1String( "prev_chapter" ) );
     ac->setDefaultShortcuts(prev_chapter, QList<QKeySequence>() << Qt::Key_Comma << Qt::Key_MediaPrevious);
     connect( prev_chapter, SIGNAL(triggered()), engine(), SLOT(prevChapter()) );
     addToAc( prev_chapter )
 
-    QAction* next_chapter = new QAction( QIcon::fromTheme(QLatin1String( "media-skip-forward" )), i18n("Next"), ac );
+    QAction* next_chapter = new QAction( QIcon::fromTheme(QLatin1String( "media-skip-forward" )), i18nc("@action next chapter", "Next"), ac );
     next_chapter->setObjectName( QLatin1String( "next_chapter" ) );
     ac->setDefaultShortcuts(next_chapter, QList<QKeySequence>() << Qt::Key_Period << Qt::Key_MediaNext);
     connect( next_chapter, SIGNAL(triggered()), engine(), SLOT(nextChapter()) );
     addToAc( next_chapter )
 
     // xgettext: no-c-format
-    QAction* tenPercentBack = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-backward" )), i18n("Return 10% Back"), ac );
+    QAction* tenPercentBack = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-backward" )), i18nc("@action", "Return 10% Back"), ac );
     tenPercentBack->setObjectName( QLatin1String( "ten_percent_back" ) );
     ac->setDefaultShortcut(tenPercentBack, Qt::Key_PageUp);
     connect( tenPercentBack, SIGNAL(triggered()), engine(), SLOT(tenPercentBack()) );
     addToAc( tenPercentBack )
 
     // xgettext: no-c-format
-    QAction* tenPercentForward = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-forward" )), i18n("Go 10% Forward"), ac );
+    QAction* tenPercentForward = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-forward" )), i18nc("@action", "Go 10% Forward"), ac );
     tenPercentForward->setObjectName( QLatin1String( "ten_percent_forward" ) );
     ac->setDefaultShortcut(tenPercentForward, Qt::Key_PageDown);
     connect( tenPercentForward, SIGNAL(triggered()), engine(), SLOT(tenPercentForward()) );
     addToAc( tenPercentForward )
 
-    QAction* tenSecondsBack = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-backward" )), i18n("Return 10 Seconds Back"), ac );
+    QAction* tenSecondsBack = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-backward" )), i18nc("@action", "Return 10 Seconds Back"), ac );
     tenSecondsBack->setObjectName( QLatin1String( "ten_seconds_back" ) );
     ac->setDefaultShortcut(tenSecondsBack, Qt::Key_Minus);
     connect( tenSecondsBack, SIGNAL(triggered()), engine(), SLOT(tenSecondsBack()) );
     addToAc( tenSecondsBack )
 
-    QAction* tenSecondsForward = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-forward" )), i18n("Go 10 Seconds Forward"), ac );
+    QAction* tenSecondsForward = new QAction( QIcon::fromTheme(QLatin1String( "media-seek-forward" )), i18nc("@action", "Go 10 Seconds Forward"), ac );
     tenSecondsForward->setObjectName( QLatin1String( "ten_seconds_forward" ) );
     ac->setDefaultShortcut(tenSecondsForward, Qt::Key_Plus);
     connect( tenSecondsForward, SIGNAL(triggered()), engine(), SLOT(tenSecondsForward()) );
@@ -475,7 +476,7 @@ MainWindow::toggleVolumeSlider( bool show )
         m_volumeSlider->setFocus(Qt::PopupFocusReason);
 
         m_muteCheckBox = new QCheckBox();
-        m_muteCheckBox->setText( i18nc( "Mute the sound output", "Mute" ) );
+        m_muteCheckBox->setText( i18nc( "@option:check Mute the sound output", "Mute" ) );
         m_muteCheckBox->setChecked ( engine()->isMuted() );
         connect( m_muteCheckBox, SIGNAL(toggled(bool)), videoWindow(), SLOT(mute(bool)) );
 
@@ -575,7 +576,11 @@ MainWindow::load( const QUrl &url )
     // check if an UDS_LOCAL_PATH is defined.
     if (!ret && KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local")) {
         //#define UDS_LOCAL_PATH (7 | KIO::UDS_STRING)
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 69, 0)
+        KIO::StatJob * job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatBasic);
+#else
         KIO::StatJob * job = KIO::stat(url, KIO::StatJob::SourceSide, 2);
+#endif
         KJobWidgets::setWindow(job, this);
         if (job->exec()) {
             KIO::UDSEntry e = job->statResult();
@@ -631,7 +636,7 @@ MainWindow::openFileDialog()
 
     static QUrl lastDirectory;
 
-    QFileDialog dlg(this, i18n("Select File to Play"));
+    QFileDialog dlg(this, i18nc("@title:window", "Select File to Play"));
     dlg.setAcceptMode(QFileDialog::AcceptOpen);
     dlg.setFileMode(QFileDialog::ExistingFile);
     dlg.setMimeTypeFilters(mimeFilter);
@@ -659,7 +664,7 @@ MainWindow::openFileDialog()
 void
 MainWindow::openStreamDialog()
 {
-    QUrl url = QUrl::fromUserInput(QInputDialog::getText( this, i18nc("@title:window", "Stream to Play"), i18n("Stream:") ));
+    QUrl url = QUrl::fromUserInput(QInputDialog::getText( this, i18nc("@title:window", "Stream to Play"), i18nc("@label:textbox", "Stream:") ));
 
     if( url.isEmpty() ) {
         qDebug() << "URL empty in MainWindow::openStreamDialog()";
